package org.abtollc.api;

import java.util.List;

interface ISipConfiguration {
	
	void resetAllDefaultValues();
    // Api compat part
    boolean getPreferenceBooleanValue2(in String string, boolean b);

    boolean getPreferenceBooleanValue(in String string);

     String getPreferenceStringValue(String key);

     String getPreferenceStringValue2(String key, String defaultVal);


     int getPreferenceIntegerValue(String key);
    
     int getPreferenceIntegerValue2(in String key, int i);

     float getPreferenceFloatValue(String key);

     float getPreferenceFloatValue2(String key, float f);

     void setPreferenceStringValue(String key, String newValue);

     void setPreferenceBooleanValue(String key, boolean newValue);

     void setPreferenceFloatValue(String key, float newValue);

    // Network part

    /**
     * Say whether current connection is valid for outgoing calls
     *
     * @return true if connection is valid
     */
     boolean isValidConnectionForOutgoing();

    /**
     * Say whether current connection is valid for incoming calls
     *
     * @return true if connection is valid
     */
     boolean isValidConnectionForIncoming();

     List<String> getAllIncomingNetworks();

     int getLogLevel();

    /**
     * Get the audio codec quality setting
     *
     * @return     the audio quality
     */
     int getInCallMode();


    /**
     * Get current clock rate
     *
     * @return clock rate in Hz
     */
     long getClockRate();


     boolean useRoutingApi();

     boolean useModeApi();


     boolean generateForSetCall();


     float getInitialVolumeLevel();


    /**
     * Get sip ringtone
     *
     * @return string uri
     */
     String getRingtone();


    /// ---- PURE SIP SETTINGS -----

     boolean isTCPEnabled();

     boolean isUDPEnabled();

     boolean isTLSEnabled();

     boolean useIPv6();

     int getUDPTransportPort();

     int getTCPTransportPort();

     int getTLSTransportPort();


    /**
     * Retrieve UDP keep alive interval for the current connection
     *
     * @return KA Interval in second
     */
     int getUdpKeepAliveInterval();

    /**
     * Retrieve TCP keep alive interval for the current connection
     *
     * @return KA Interval in second
     */
     int getTcpKeepAliveInterval();

    /**
     * Retrieve TLS keep alive interval for the current connection
     *
     * @return KA Interval in second
     */
     int getTlsKeepAliveInterval();

     int getRTPPort();

     boolean enableDNSSRV();

     int getDSCPVal();

     int getTLSMethod();

     String getUserAgent();


    /**
     * Get a property from android property subsystem
     *
     * @param prop property to get
     * @return the value of the property command line or null if failed
     */
     String getSystemProp(String prop);

    /**
     * Action do do when headset is pressed
     *
     * @return
     */
     int getHeadsetAction();

    //Media part

    /**
     * Get auto close time after end of the call
     * To avoid crash after hangup -- android 1.5 only but
     * even sometimes crash
     */
     int getAutoCloseTime();

    /**
     * Whether echo cancellation is enabled
     *
     * @return true if enabled
     */
     boolean hasEchoCancellation();

     long getEchoCancellationTail();

    /**
     * Get the audio codec quality setting
     *
     * @return the audio quality
     */
     long getMediaQuality();

    /**
     * Get whether ice is enabled
     *
     * @return 1 if enabled (pjstyle)
     */
     int getIceEnabled();

    /**
     * Get whether turn is enabled
     *
     * @return 1 if enabled (pjstyle)
     */
     int getTurnEnabled();

    /**
     * Get whether turn is enabled
     *
     * @return 1 if enabled (pjstyle)
     */
     int getStunEnabled();

    /**
     * Get turn server
     *
     * @return host:port or blank if not set
     */
     String getTurnServer();

     void setLibCapability(String cap, boolean canDo);

    // DTMF

     boolean useSipInfoDtmf();
     
     boolean forceDtmfInBand();

     boolean forceDtmfRTP();

    // Codecs

     void setCodecList(in List<String> codecs);
    
     void setVideoCodecList(in List<String> codecs);

    /**
     * Get the codec priority
     *
     * @param codecName    codec name formated in the pjsip format (the
     *                     corresponding pref is
     *                     codec_{{lower(codecName)}}_{{codecFreq}})
     * @param defaultValue the default value if the pref is not found MUST be
     *                     casteable as Integer/short
     * @return the priority of the codec as defined in preferences
     */
     int getCodecPriority(in String codecName, in String type, in String defaultValue);

    /**
     * Set the priority for the codec for a given bandwidth type
     *
     * @param codecName the name of the codec as announced by codec
     * @param type      bandwidth type <br/>
     *                  For now, valid constants are :
     *                  {@link SipConfigManager#CODEC_NB} and
     *                  {@link SipConfigManager#CODEC_WB}
     * @param newValue  Short value for preference as a string.
     */
     void setCodecPriority(String codecName, String type, String newValue);
}